/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWITKIO_UT_HELPER_HPP__
#define __FWITKIO_UT_HELPER_HPP__

namespace fwData
{
class Image;
}

namespace fwItkIO
{
namespace ut
{
namespace helper
{

void roundSpacing( SPTR(::fwData::Image) image);

} //namespace helper
} //namespace ut
} //namespace fwItkIO


#endif // __FWITKIO_UT_HELPER_HPP__
